@@ -7,8 +7,8 @@
  */
 #include "kbiff.h"
 #include "kbiff.moc"
-#include <ntqmovie.h>
-#include <ntqtooltip.h>
+#include <tqmovie.h>
+#include <tqtooltip.h>
 
 #include <kaudioplayer.h>
 #include <tdeconfig.h>
